@@ -1,4 +1,5 @@
 """Manage API calls and IO procedures."""
+import binascii
 import json
 import logging
 import os
@@ -372,3 +373,25 @@ def ml_ft_upload(params):
     )
 
     return
+
+
+def cached_query(params, query):
+    """Return query result via caching."""
+    client, job_config = get_bq_client(params)
+    today = datetime.utcnow()
+    checksum = binascii.crc32(bytes(query, "ascii")) % (2**32)
+    cache_path = f"data/query_{today.strftime(params['date_fmt'])}_{checksum:x}.pkl.gz"
+
+    # Cache Hit, unpickle the file
+    if os.path.exists(cache_path):
+        logger.info("Using cached Query..")
+        with pgzip.open(cache_path, "rb") as f:
+            return pickle.load(f)
+    else:
+        logger.info("Cached query couldn't found, downloading..")
+        df = client.query(query=query, job_config=job_config).to_dataframe(
+            progress_bar_type="tqdm"
+        )
+        with pgzip.open(cache_path, "wb") as f:
+            pickle.dump(df, f)
+        return df
