@@ -572,8 +572,8 @@ def calculate_single_lift_curve(y, y_pred, step=0.01):
     # Define an auxiliary dataframe to plot the curve
     aux_lift = pd.DataFrame()
     # Create a real and predicted column for our new DataFrame and assign values
-    aux_lift["real"] = y
-    aux_lift["predicted"] = y_pred
+    aux_lift["real"] = y.values
+    aux_lift["predicted"] = y_pred.values
     # Order the values for the predicted probability column:
     aux_lift.sort_values("predicted", ascending=False, inplace=True)
 
@@ -596,16 +596,15 @@ def calculate_single_lift_curve(y, y_pred, step=0.01):
     return list(x_val * 100), list(y_v)
 
 
-
 def calculate_lift_curve(params, data):
     """Calculate All Lift curves."""
-    res = {}
-    res["lift_train"] = calculate_single_lift_curve(
-        data["label_train"], data["pred_train"]
-    )
-    res["lift_val"] = calculate_single_lift_curve(data["label_val"], data["pred_val"])
+    segment_list = ["train", "val"]
     if "validation_test_split" in params and params["validation_test_split"]:
-        res["lift_test"] = calculate_single_lift_curve(
-            data["label_test"], data["pred_test"]
+        segment_list = ["train", "val", "test"]
+
+    return {
+        f"lift_{segment}": calculate_single_lift_curve(
+            data[f"label_{segment}"], data[f"pred_{segment}"]
         )
-    return res
+        for segment in segment_list
+    }
